@@ -11,6 +11,7 @@ import imagesize
 from .cover_page_ams import create_cover_page
 from .cover_page_project import create_project_cover
 from .directory import get_images
+from .mv import create_mv_folder
 
 font_dir = Path('X:/9999_BID_AMS/AMS-VFB_Fonts')
 
@@ -36,7 +37,8 @@ def get_cwd():
 def main():
     click.echo(f"🥰 Let's create a briefing {os.getlogin()}!")
     pdf = FPDF(orientation='L', format='A4')
-
+    pdf.set_author('Animotions')
+    pdf.set_creator(os.getlogin())
     pdf.add_font(family='montserrat',
                  fname=font_dir.joinpath("Montserrat-ExtraBold.ttf"),
                  uni=True)
@@ -58,6 +60,8 @@ def main():
 
     create_cover_page(pdf)
     create_project_cover(pdf, project_name)
+    pdf.set_subject(project_name)
+    pdf.set_title(f"Briefing - {project_name}")
 
     proj_number = str(project_path)[3:7]
 
@@ -84,14 +88,10 @@ def main():
 
         pdf.image(str(f), x=80, y=15+(frame_height - ratio_y)/2, w=200)
 
-    mv = project_path.joinpath('MV')
+    #mv = project_path.joinpath('MV')
 
-    # mvs = [int(x[0:1]) for x in os.listdir(mv)]
+    mv_dir = create_mv_folder(project_path, verbose=True)
 
-    # print(max(mvs))
-
-    # datum = date.today().strftime("%Y%m%d")
-    # dirname = os.path.join(mv, f'{max(mvs)+1}_{datum}_pov_brief')
-    dest = mv.joinpath('pov_brief.pdf')
+    dest = mv_dir.joinpath('pov_brief.pdf')
     pdf.output(dest, 'F')
     webbrowser.open(dest)
